@@ -34,6 +34,8 @@
 #include <config.h>
 #endif
 
+#include <dbus/dbus-glib.h>
+
 #if HILDON == 1
 #include <hildon/hildon.h>
 #else
@@ -135,8 +137,8 @@ void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 			safeReplaceString(&rec->group, gtk_combo_box_get_active_text(GTK_COMBO_BOX(recwindow->group)), mainview);
 			buffer=gtk_text_view_get_buffer (GTK_TEXT_VIEW(recwindow->notes));
 #else
-			safeReplaceString(&rec->group, hildon_touch_selector_get_current_text(HILDON_TOUCH_SELECTOR(recwindow->group)), mainview);
-			buffer=hildon_text_view_get_buffer (HILDON_TEXT_VIEW(recwindow->notes));
+			safeReplaceString(&rec->group, hildon_button_get_value(HILDON_BUTTON(recwindow->group)), mainview);
+			buffer=hildon_text_view_get_buffer(HILDON_TEXT_VIEW(recwindow->notes));
 #endif
 			if (gtk_text_buffer_get_modified(buffer)) { /* update notes if buffer has changed */
 				gtk_text_buffer_get_start_iter (buffer, &start);
@@ -171,6 +173,143 @@ void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 	}
 }
 
+void setUrlTag(GtkTextBuffer *buffer, gint posStart, gint posEnd) {
+	GtkTextIter start, end;
+	gtk_text_buffer_get_iter_at_offset(buffer, &start, posStart);
+	gtk_text_buffer_get_iter_at_offset(buffer, &end, posEnd);
+	gtk_text_buffer_apply_tag_by_name(buffer, "url", &start, &end);
+
+}
+
+#if MAEMO_VERSION_MAJOR < 5
+void enhanceBufferWithString(GtkTextBuffer *buffer, const gchar *search) {
+	GtkTextIter start, end;
+	gchar *text, *bout, *oneChar;
+	gunichar uniChar;
+	gint posStart, posEnd, index, listIdx;
+	gchar **list, **searchList;
+	
+	gtk_text_buffer_get_bounds(buffer, &start, &end);
+	text = gtk_text_buffer_get_slice(buffer, &start, &end, TRUE);
+	if (text == NULL || text[0] == '\0') {
+		return;
+	}
+	list = g_strsplit_set(text, " \t\r\n", -1);
+	searchList = g_strsplit(search, " ", -1);
+	index = 0;
+	posStart = 0;
+	while (list[index]) {
+		posEnd = posStart + g_utf8_strlen(list[index], -1);
+		if (posEnd > posStart) {
+			bout = g_ascii_strdown(list[index], -1);
+			listIdx = 0;
+			while (searchList[listIdx]) {
+				if (g_str_has_prefix(bout, searchList[listIdx])) {
+					setUrlTag(buffer, posStart, posEnd);
+					break;
+				}
+				listIdx ++;
+			}
+			g_free(bout);
+		}
+		posStart =  posEnd + 1;
+		index++;
+	}
+	g_strfreev(list);
+	g_strfreev(searchList);
+}
+#else
+void enhanceBufferWithRegex(GtkTextBuffer *buffer, GRegex *regex) {
+	GtkTextIter start, end;
+	gchar *text;
+	GMatchInfo *matchInfo;
+	GError *error = NULL;
+	gint posStart, posEnd;
+	
+	gtk_text_buffer_get_bounds(buffer, &start, &end);
+	text = gtk_text_buffer_get_slice(buffer, &start, &end, TRUE);
+	
+	g_regex_match_full(regex, text, -1, 0, 0, &matchInfo, &error);
+	while (g_match_info_matches(matchInfo)) {
+		if (g_match_info_fetch_pos(matchInfo, 0, &posStart, &posEnd)) {
+			setUrlTag(buffer, posStart, posEnd);
+		}
+		g_match_info_next(matchInfo, &error);
+	}
+	g_match_info_free(matchInfo);
+	if (error != NULL) {
+		g_printerr("Error while mathing: %s\n", error->message);
+		g_error_free(error);
+	}
+}
+#endif
+
+void callback_buffer_changed(GtkTextBuffer *buffer, MainView *mainview) {
+	GtkTextIter start, end;
+	
+	gtk_text_buffer_get_bounds(buffer, &start, &end);
+	gtk_text_buffer_remove_all_tags(buffer, &start, &end);
+
+#if MAEMO_VERSION_MAJOR < 5
+	enhanceBufferWithString(buffer, "http:// https:// www.");
+#else
+	enhanceBufferWithRegex(buffer, mainview->regexHttp);
+	enhanceBufferWithRegex(buffer, mainview->regexWww);
+#endif
+}
+
+static void launch_browser (gchar *url, MainView *mainView) {
+  DBusGConnection *connection;
+  GError *error = NULL;
+
+  DBusGProxy *proxy;
+
+  connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+  if (connection == NULL) {
+      msgbox(mainView, error->message);
+      g_error_free (error);
+      return;
+    }
+
+  proxy = dbus_g_proxy_new_for_name (connection,
+				     "com.nokia.osso_browser",
+				     "/com/nokia/osso_browser/request",
+				     "com.nokia.osso_browser");
+
+  error = NULL;
+  if (!dbus_g_proxy_call (proxy, "load_url", &error,
+			  G_TYPE_STRING, url,
+			  G_TYPE_INVALID,
+			  G_TYPE_INVALID)) {
+      msgbox(mainView, error->message);
+      g_error_free (error);
+    }
+}
+
+
+gboolean callback_tag_event(GtkTextTag *tag, GObject *object, GdkEvent *event, GtkTextIter *iter, MainView *mainView) {
+	GtkTextIter start, end;
+	gchar *text;
+	if (event->type == GDK_BUTTON_PRESS && !gtk_text_view_get_editable(GTK_TEXT_VIEW(object))) {
+		start = *iter; 
+		while (!gtk_text_iter_begins_tag(&start, tag)) {
+			if (!gtk_text_iter_backward_char(&start)) {
+				break;
+			}
+		}
+		end = *iter; 
+		while (!gtk_text_iter_ends_tag(&end, tag)) {
+			if (!gtk_text_iter_forward_char(&end)) {
+				break;
+			}
+		}
+		text = gtk_text_iter_get_text(&start, &end);
+		g_print("text associ au tag %s\n", text);
+		launch_browser(text, mainView);
+	}
+	return FALSE;
+}
+
 /* Callback for hardware D-BUS events */
 void hw_event_handler(osso_hw_state_t *state, MainView *mainview) {
  	g_assert(mainview != NULL && mainview->data != NULL );
