@@ -60,7 +60,7 @@ char readbytes(MainView* mainview, GnomeVFSHandle *handle, unsigned char *ptr, u
 	gnome_vfs_read(handle, ptr, bytes, &in_bytes);
 	if (in_bytes!=bytes) {
 		interface_error(PWSAFE_ERROR_OPEN_FAILED, mainview);
-		gnome_vfs_close(handle);
+//		gnome_vfs_close(handle);
 		return FALSE;
 	}
 	return TRUE;
@@ -246,7 +246,7 @@ char testpassword(MainView* mainview, GnomeVFSHandle *handle) {
 	GenRandhash(mainview->pass, rnd, rndhash2);
 	if (memcmp(rndhash, rndhash2, sizeof(rndhash))!=0) {
 		interface_error(PWSAFE_ERROR_BADPASS, mainview);
-		gnome_vfs_close(handle);
+//		gnome_vfs_close(handle);
 		return FALSE;
 	}
 	return TRUE;
@@ -409,6 +409,7 @@ gboolean pwsafe_file_open_error(MainView *mainview, GnomeVFSResult vfs_result) {
 }
 
 void read_pwsafe_file(MainView* mainview) {
+	gboolean valid = FALSE;
 	/* get password */
 	gchar *file_utf8;
 	g_assert(mainview!=NULL);
@@ -417,9 +418,6 @@ void read_pwsafe_file(MainView* mainview) {
 	mainview->pass=get_password(mainview, file_utf8);
 	g_free(file_utf8);
 	
-	// Fred manage interface
-	interface_show_state(mainview);
-
 	if (mainview->pass) {
 		GnomeVFSResult vfs_result;
 		GnomeVFSHandle *handle = NULL;
@@ -472,6 +470,7 @@ void read_pwsafe_file(MainView* mainview) {
 									entry=g_malloc0(sizeof(rec));
 									entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
 									recs=NULL;
+									valid = TRUE;
 									/* read and decrypt the blocks. store the settings for each one, and write them to the tree on each END */
 									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 									do {
@@ -527,11 +526,17 @@ void read_pwsafe_file(MainView* mainview) {
 							}
 						}
 					}
+					mainview->last_file=mainview->file_name;
+					conf_save_string(CONF_LASTFILE, mainview->last_file);
 				}
-				mainview->last_file=mainview->file_name;
-				conf_save_string(CONF_LASTFILE, mainview->last_file);
+				gnome_vfs_close(handle);
 			}
-			gnome_vfs_close(handle);
 		}
 	}
+	if (!valid) {
+		mainview->pass=NULL;
+	}
+	// Fred manage interface
+	interface_show_state(mainview);
+
 }
