@@ -93,12 +93,21 @@ MainView* interface_main_view_new( AppData *data ) {
 //	osso_application_set_exit_cb( data->osso, exit_event_handler, result);
 	g_signal_connect (G_OBJECT(data->main_view), "delete_event", G_CALLBACK(exit_event_handler), result);	/* top right X, etc. */
 	g_signal_connect(G_OBJECT(result->data->main_view), "key_press_event", G_CALLBACK(callback_key_press), result);
+	
+#if MAEMO_VERSION_MAJOR >= 5
+	result->regexHttp = g_regex_new("http(s?)://[\\S]+", G_REGEX_CASELESS, 0, NULL);
+	result->regexWww = g_regex_new("www\\.[\\S]+", G_REGEX_CASELESS, 0, NULL);
+#endif
 	return result; /* Return new mainview handle */
 }
 
 
 /* clean up the allocated memory */
 void interface_main_view_destroy( MainView *main ) {
+#if MAEMO_VERSION_MAJOR >= 5
+	g_regex_unref(main->regexHttp);
+	g_regex_unref(main->regexWww);
+#endif
 	g_free( main );
 }
 
@@ -160,7 +169,11 @@ gboolean fillCombo (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, G
 
 void show_rec(MainView *main, rec *r) {
 	GtkWidget *sizer, *scrollwindow;
+#if MAEMO_VERSION_MAJOR >= 5
+	GtkWidget *selector;
+#endif
 	GtkTextBuffer *buffer=NULL;
+	GtkTextTag *tag;
 	RecWindow *rec_win;
 	if (main->rec_win!=NULL) return; /* don't show two rec windows at once */
 	rec_win=g_malloc0(sizeof(RecWindow));
@@ -170,7 +183,9 @@ void show_rec(MainView *main, rec *r) {
 	rec_win->delete_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), GTK_STOCK_DELETE, 4);
 	rec_win->edit_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), _("Edit"), 5);
 /*	gtk_button_set_image(GTK_BUTTON(rec_win->edit_button), GTK_STOCK_EDIT); */
+#if MAEMO_VERSION_MAJOR < 5
 	g_object_set(rec_win->dialog, "content-area-border", 1, "button_spacing", 20, NULL);
+#endif
     /*  where's "button-spacing", "content-area-border", "action_area_border" ? - not in scratchbox, maybe on n800 */
 	g_signal_connect(rec_win->dialog, "response", G_CALLBACK ( callback_rec_response), main);
 	sizer=gtk_table_new(5, 4, TRUE);
@@ -184,16 +199,23 @@ void show_rec(MainView *main, rec *r) {
 		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(rec_win->group))), r->group);
 	}
 	gtk_table_attach_defaults(GTK_TABLE(sizer), rec_win->group, 3, 4, 0, 1);
-#else
-	rec_win->group=hildon_touch_selector_entry_new_text();
-	hildon_entry_set_placeholder(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(rec_win->group)), _("Group"));
-	if (r->group!=NULL) {
-		hildon_entry_set_text(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(rec_win->group)), r->group);
-	}
-	gtk_table_attach_defaults(GTK_TABLE(sizer), rec_win->group, 2, 4, 0, 1);
-#endif
 	// Fill the combo
 	gtk_tree_model_foreach(GTK_TREE_MODEL(main->store), (GtkTreeModelForeachFunc) fillCombo, (gpointer) rec_win->group);
+#else
+	rec_win->group=hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+	hildon_button_set_title (HILDON_BUTTON(rec_win->group), _("Group"));
+	
+	selector=hildon_touch_selector_entry_new_text();
+	hildon_entry_set_placeholder(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(selector)), _("Group"));
+	if (r->group!=NULL) {
+		hildon_entry_set_text(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(selector)), r->group);
+	}
+	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (rec_win->group), HILDON_TOUCH_SELECTOR (selector));
+
+	gtk_table_attach_defaults(GTK_TABLE(sizer), rec_win->group, 2, 4, 0, 1);
+	// Fill the combo
+	gtk_tree_model_foreach(GTK_TREE_MODEL(main->store), (GtkTreeModelForeachFunc) fillCombo, (gpointer) selector);
+#endif
 	
 	rec_win->username=show_rec_line(sizer, _("Username"), r->user, 1, 0);
 	rec_win->password=show_rec_line(sizer, _("Password"), r->password, 1, 2);
@@ -207,8 +229,14 @@ void show_rec(MainView *main, rec *r) {
 	rec_win->notes= hildon_text_view_new();
 	hildon_text_view_set_placeholder(HILDON_TEXT_VIEW(rec_win->notes), _("Notes"));
 	buffer=hildon_text_view_get_buffer(HILDON_TEXT_VIEW(rec_win->notes));
+	hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(rec_win->notes), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_MULTILINE);
 	scrollwindow=hildon_pannable_area_new();
 #endif
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(rec_win->notes), GTK_WRAP_WORD_CHAR);
+	tag = gtk_text_buffer_create_tag(buffer, "url", "underline", PANGO_UNDERLINE_SINGLE, NULL);
+	g_signal_connect( G_OBJECT(buffer), "changed", G_CALLBACK(callback_buffer_changed), main);
+	g_signal_connect( G_OBJECT(tag), "event", G_CALLBACK(callback_tag_event), main);
+	
 	if (r->notes!=NULL) gtk_text_buffer_set_text (buffer, r->notes, -1);
 	gtk_text_buffer_set_modified (buffer, FALSE);
 	gtk_container_add (GTK_CONTAINER (scrollwindow), rec_win->notes);
@@ -494,11 +522,13 @@ void interface_show_state(MainView *main) {
 	interface_show_item(main->add_item, fopen);
 	
 	if (GTK_IS_WIDGET(main->new_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
+#if MAEMO_VERSION_MAJOR < 5
 		gtk_widget_set_sensitive(GTK_WIDGET(main->new_tb), !fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->open_tb), !fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->close_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->save_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->saveas_tb), fopen);
+#endif
 		gtk_widget_set_sensitive(GTK_WIDGET(main->change_password_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->add_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->filter_tb), fopen);
@@ -519,7 +549,7 @@ void interface_set_rec_editable(RecWindow* rec_win, gboolean editable) {
 	// Group is a comboBoxEdit
 	gtk_editable_set_editable(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(rec_win->group))), editable);
 #else
-	gtk_editable_set_editable(GTK_EDITABLE(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR(rec_win->group))), editable);
+	gtk_widget_set_sensitive(GTK_WIDGET(rec_win->group), editable);
 #endif
 	gtk_editable_set_editable(GTK_EDITABLE(rec_win->username), editable);
 	gtk_editable_set_editable(GTK_EDITABLE(rec_win->password), editable);
@@ -537,12 +567,14 @@ static void create_toolbar ( MainView *main ) {
 
 	/* Make menus and buttons to toolbar: */
 	/* Create toolitems using defined items from stock */
+#if MAEMO_VERSION_MAJOR < 5
 	main->new_tb = gtk_tool_button_new_from_stock(GTK_STOCK_NEW);
 	main->open_tb = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
 	main->close_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CLOSE);
 	main->save_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
 	main->saveas_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE_AS);
 	main->separator_tb1 = gtk_separator_tool_item_new();
+#endif
 	main->add_tb = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
 	main->change_password_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CONVERT);
 	main->separator_tb2 = gtk_separator_tool_item_new();
@@ -563,12 +595,14 @@ static void create_toolbar ( MainView *main ) {
     gtk_container_add( GTK_CONTAINER( main->filter_item_tb ) , main->filter_tb);
 	
     /* Insert items to toolbar */
+#if MAEMO_VERSION_MAJOR >= 5
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->new_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->open_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->close_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->save_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->saveas_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb1, -1);
+#endif
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->add_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->change_password_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb2, -1);
@@ -579,16 +613,16 @@ static void create_toolbar ( MainView *main ) {
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->filter_item_tb, -1);
 
 	/* Connect signals to buttons */
+#if MAEMO_VERSION_MAJOR < 5
 	g_signal_connect(G_OBJECT(main->new_tb), "clicked", G_CALLBACK(callback_file_new), main);
 	g_signal_connect(G_OBJECT(main->open_tb), "clicked", G_CALLBACK(callback_file_open), main);
 	g_signal_connect(G_OBJECT(main->close_tb), "clicked", G_CALLBACK(callback_file_close), main);
 	g_signal_connect(G_OBJECT(main->save_tb), "clicked", G_CALLBACK(callback_file_save), main);
 	g_signal_connect(G_OBJECT(main->saveas_tb), "clicked", G_CALLBACK(callback_file_saveas), main);
-	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
-	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
-#if MAEMO_VERSION_MAJOR < 5
 	g_signal_connect(G_OBJECT(main->fullscreen_tb), "clicked", G_CALLBACK(callback_fullscreen), main);
 #endif
+	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
+	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
 	g_signal_connect(G_OBJECT(main->filter_tb), "activate", G_CALLBACK(callback_filter), main);
 	
 	/* Attach toolbar to main view */
