@@ -76,6 +76,11 @@ typedef struct RecWindow {
 	GtkWidget *edit_button;
 } RecWindow;
 
+typedef struct SearchGroup {
+	rec *data;
+	gboolean found;
+} SearchGroup;
+
 /* Struct to include view's information */
 typedef struct _MainView MainView;
 struct _MainView
@@ -96,8 +101,6 @@ struct _MainView
 	GtkWidget *saveas_item;
     GtkWidget *export_item;
 	GtkWidget *view_item;
-	GtkWidget *large_icons_item;
-	GtkWidget *small_icons_item;
 	GtkWidget *add_item;
 	GtkWidget *change_password;
 	GtkWidget *fullscreen_item;
@@ -121,9 +124,8 @@ struct _MainView
 
 	GtkWidget* mainwindow;
 
-	GtkWidget* iconView;
-	GtkListStore  *store;
-	GtkIconSize iconSize;
+	GtkWidget* treeView;
+	GtkTreeStore  *store;
 
 	GtkClipboard* clipboard;	/* clipboard for copy/paste */
 	PangoFontDescription* font_desc;
@@ -133,6 +135,8 @@ struct _MainView
 	gchar* pass;			/* must be stored to be able to write file again... */
 	gchar *preferences;		/* preferences from the file... just written back out. */
 	RecWindow* rec_win;		/*active recwindow object... one per app */
+	GRegex *regexHttp;
+	GRegex *regexWww;
 };
 
 /* Publics: */
@@ -143,15 +147,14 @@ PangoFontDescription* interface_font_chooser( MainView * main );
 gint interface_yes_no_note(MainView * main, gchar *title);
 void interface_error( PwsafeError me, MainView *main );
 void msgbox(MainView* main, char *msg);
-void populate_iconView (MainView *main, char *group);
+void populate_treeView (MainView *main);
 void show_rec(MainView *main, rec *record);
-void empty_iconView(MainView *main);
+void empty_treeView(MainView *main);
 void unshow_rec(MainView *main);
 gchar *get_password(MainView *main, gchar *caption);
 void interface_show_state(MainView *main);
 char *emptynull(char *a);
 void interface_fullscreen(MainView *mainview);
-void interface_set_icon_size(MainView *mainview, gchar *style) ;
 void interface_set_rec_editable(RecWindow* rec_win, gboolean editable);
 
 #endif
